Class: Google::Analytics::Data::V1beta::CohortReportSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/data/v1beta/data.rb

Overview

Optional settings of a cohort report.

Instance Attribute Summary collapse

Instance Attribute Details

#accumulate ⇒ ::Boolean

Returns If true, accumulates the result from first touch day to the end day. Not supported in RunReportRequest.

Returns:

  • (::Boolean) —

    If true, accumulates the result from first touch day to the end day. Not supported in RunReportRequest.



611
612
613
614
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 611

class CohortReportSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end