Class: Google::Analytics::Data::V1beta::MetricMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/data/v1beta/data.rb

Overview

Explains a metric.

Instance Attribute Summary collapse

Instance Attribute Details

#api_name ⇒ ::String

Returns A metric name. Useable in Metric's name. For example, eventCount.

Returns:

  • (::String) —

    A metric name. Useable in Metric's name. For example, eventCount.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#custom_definition ⇒ ::Boolean

Returns True if the metric is a custom metric for this property.

Returns:

  • (::Boolean) —

    True if the metric is a custom metric for this property.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deprecated_api_names ⇒ ::Array<::String>

Returns Still usable but deprecated names for this metric. If populated, this metric is available by either apiName or one of deprecatedApiNames for a period of time. After the deprecation period, the metric will be available only by apiName.

Returns:

  • (::Array<::String>) —

    Still usable but deprecated names for this metric. If populated, this metric is available by either apiName or one of deprecatedApiNames for a period of time. After the deprecation period, the metric will be available only by apiName.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description ⇒ ::String

Returns Description of how this metric is used and calculated.

Returns:

  • (::String) —

    Description of how this metric is used and calculated.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#expression ⇒ ::String

Returns The mathematical expression for this derived metric. Can be used in Metric's expression field for equivalent reports. Most metrics are not expressions, and for non-expressions, this field is empty.

Returns:

  • (::String) —

    The mathematical expression for this derived metric. Can be used in Metric's expression field for equivalent reports. Most metrics are not expressions, and for non-expressions, this field is empty.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type ⇒ ::Google::Analytics::Data::V1beta::MetricType

Returns The type of this metric.

Returns:



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ui_name ⇒ ::String

Returns This metric's name within the Google Analytics user interface. For example, Event count.

Returns:

  • (::String) —

    This metric's name within the Google Analytics user interface. For example, Event count.



857
858
859
860
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 857

class MetricMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end