Class: Google::Analytics::Data::V1beta::OrderBy::MetricOrderBy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/data/v1beta/data.rb

Overview

Sorts by metric values.

Instance Attribute Summary collapse

Instance Attribute Details

#metric_name ⇒ ::String

Returns A metric name in the request to order by.

Returns:

  • (::String) —

    A metric name in the request to order by.



360
361
362
363
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 360

class MetricOrderBy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end