Class: Google::Analytics::Data::V1beta::PropertyQuota

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/analytics/data/v1beta/data.rb

Overview

Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors.

Instance Attribute Summary collapse

Instance Attribute Details

#concurrent_requests ⇒ ::Google::Analytics::Data::V1beta::QuotaStatus

Returns Standard Analytics Properties can send up to 10 concurrent requests; Analytics 360 Properties can use up to 50 concurrent requests.

Returns:



785
786
787
788
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 785

class PropertyQuota
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#potentially_thresholded_requests_per_hour ⇒ ::Google::Analytics::Data::V1beta::QuotaStatus

Returns Analytics Properties can send up to 120 requests with potentially thresholded dimensions per hour. In a batch request, each report request is individually counted for this quota if the request contains potentially thresholded dimensions.

Returns:

  • (::Google::Analytics::Data::V1beta::QuotaStatus) —

    Analytics Properties can send up to 120 requests with potentially thresholded dimensions per hour. In a batch request, each report request is individually counted for this quota if the request contains potentially thresholded dimensions.



785
786
787
788
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 785

class PropertyQuota
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#server_errors_per_project_per_hour ⇒ ::Google::Analytics::Data::V1beta::QuotaStatus

Returns Standard Analytics Properties and cloud project pairs can have up to 10 server errors per hour; Analytics 360 Properties and cloud project pairs can have up to 50 server errors per hour.

Returns:

  • (::Google::Analytics::Data::V1beta::QuotaStatus) —

    Standard Analytics Properties and cloud project pairs can have up to 10 server errors per hour; Analytics 360 Properties and cloud project pairs can have up to 50 server errors per hour.



785
786
787
788
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 785

class PropertyQuota
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tokens_per_day ⇒ ::Google::Analytics::Data::V1beta::QuotaStatus

Returns Standard Analytics Properties can use up to 25,000 tokens per day; Analytics 360 Properties can use 250,000 tokens per day. Most requests consume fewer than 10 tokens.

Returns:



785
786
787
788
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 785

class PropertyQuota
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tokens_per_hour ⇒ ::Google::Analytics::Data::V1beta::QuotaStatus

Returns Standard Analytics Properties can use up to 5,000 tokens per hour; Analytics 360 Properties can use 50,000 tokens per hour. An API request consumes a single number of tokens, and that number is deducted from both the hourly and daily quotas.

Returns:

  • (::Google::Analytics::Data::V1beta::QuotaStatus) —

    Standard Analytics Properties can use up to 5,000 tokens per hour; Analytics 360 Properties can use 50,000 tokens per hour. An API request consumes a single number of tokens, and that number is deducted from both the hourly and daily quotas.



785
786
787
788
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 785

class PropertyQuota
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end