Class: Google::Analytics::Data::V1beta::RunPivotReportRequest
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::RunPivotReportRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/data/v1beta/analytics_data_api.rb
Overview
The request to generate a pivot report.
Instance Attribute Summary collapse
-
#cohort_spec ⇒ ::Google::Analytics::Data::V1beta::CohortSpec
Cohort group associated with this request.
-
#comparisons ⇒ ::Array<::Google::Analytics::Data::V1beta::Comparison>
Optional.
-
#currency_code ⇒ ::String
A currency code in ISO4217 format, such as "AED", "USD", "JPY".
-
#date_ranges ⇒ ::Array<::Google::Analytics::Data::V1beta::DateRange>
The date range to retrieve event data for the report.
-
#dimension_filter ⇒ ::Google::Analytics::Data::V1beta::FilterExpression
The filter clause of dimensions.
-
#dimensions ⇒ ::Array<::Google::Analytics::Data::V1beta::Dimension>
The dimensions requested.
-
#keep_empty_rows ⇒ ::Boolean
If false or unspecified, each row with all metrics equal to 0 will not be returned.
-
#metric_filter ⇒ ::Google::Analytics::Data::V1beta::FilterExpression
The filter clause of metrics.
-
#metrics ⇒ ::Array<::Google::Analytics::Data::V1beta::Metric>
The metrics requested, at least one metric needs to be specified.
-
#pivots ⇒ ::Array<::Google::Analytics::Data::V1beta::Pivot>
Describes the visual format of the report's dimensions in columns or rows.
-
#property ⇒ ::String
A Google Analytics property identifier whose events are tracked.
-
#return_property_quota ⇒ ::Boolean
Toggles whether to return the current state of this Google Analytics property's quota.
Instance Attribute Details
#cohort_spec ⇒ ::Google::Analytics::Data::V1beta::CohortSpec
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#comparisons ⇒ ::Array<::Google::Analytics::Data::V1beta::Comparison>
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#currency_code ⇒ ::String
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#date_ranges ⇒ ::Array<::Google::Analytics::Data::V1beta::DateRange>
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dimension_filter ⇒ ::Google::Analytics::Data::V1beta::FilterExpression
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dimensions ⇒ ::Array<::Google::Analytics::Data::V1beta::Dimension>
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#keep_empty_rows ⇒ ::Boolean
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_filter ⇒ ::Google::Analytics::Data::V1beta::FilterExpression
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metrics ⇒ ::Array<::Google::Analytics::Data::V1beta::Metric>
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pivots ⇒ ::Array<::Google::Analytics::Data::V1beta::Pivot>
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#property ⇒ ::String
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#return_property_quota ⇒ ::Boolean
315 316 317 318 |
# File 'proto_docs/google/analytics/data/v1beta/analytics_data_api.rb', line 315 class RunPivotReportRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |