Class: Google::Analytics::Data::V1beta::AnalyticsData::Client
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::AnalyticsData::Client
- Includes:
- Paths
- Defined in:
- lib/google/analytics/data/v1beta/analytics_data/client.rb
Overview
Client for the AnalyticsData service.
Google Analytics reporting data service.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AnalyticsData Client class.
Instance Method Summary collapse
-
#batch_run_pivot_reports(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::BatchRunPivotReportsResponse
Returns multiple pivot reports in a batch.
-
#batch_run_reports(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::BatchRunReportsResponse
Returns multiple reports in a batch.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AnalyticsData Client instance.
-
#get_metadata(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::Metadata
Returns metadata for dimensions and metrics available in reporting methods.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AnalyticsData client object.
-
#run_pivot_report(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::RunPivotReportResponse
Returns a customized pivot report of your Google Analytics event data.
-
#run_realtime_report(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::RunRealtimeReportResponse
The Google Analytics Realtime API returns a customized report of realtime event data for your property.
-
#run_report(request, options = nil) {|response, operation| ... } ⇒ ::Google::Analytics::Data::V1beta::RunReportResponse
Returns a customized report of your Google Analytics event data.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AnalyticsData client object.
Examples
To create a new AnalyticsData client with the default configuration:
client = ::Google::Analytics::Data::V1beta::AnalyticsData::Client.new
To create a new AnalyticsData client with a custom configuration:
client = ::Google::Analytics::Data::V1beta::AnalyticsData::Client.new do |config|
config.timeout = 10.0
end
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 129 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/analytics/data/v1beta/analytics_data_api_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the scope and endpoint are unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.scope == Client.configure.scope && @config.endpoint == Client.configure.endpoint && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @analytics_data_stub = ::Gapic::ServiceStub.new( ::Google::Analytics::Data::V1beta::BetaAnalyticsData::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors ) end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AnalyticsData Client class.
See Configuration for a description of the configuration fields.
Example
To modify the configuration for all AnalyticsData clients:
::Google::Analytics::Data::V1beta::AnalyticsData::Client.configure do |config|
config.timeout = 10.0
end
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 57 def self.configure @configure ||= begin namespace = ["Google", "Analytics", "Data", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [2] } default_config.rpcs.run_report.timeout = 60.0 default_config.rpcs.run_pivot_report.timeout = 60.0 default_config.rpcs.batch_run_reports.timeout = 60.0 default_config.rpcs.batch_run_pivot_reports.timeout = 60.0 default_config.rpcs.run_realtime_report.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#batch_run_pivot_reports(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::BatchRunPivotReportsResponse #batch_run_pivot_reports(property: nil, requests: nil) ⇒ ::Google::Analytics::Data::V1beta::BatchRunPivotReportsResponse
Returns multiple pivot reports in a batch. All reports must be for the same GA4 Property.
539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 539 def batch_run_pivot_reports request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::BatchRunPivotReportsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_run_pivot_reports..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "property" => request.property } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.batch_run_pivot_reports.timeout, metadata: , retry_policy: @config.rpcs.batch_run_pivot_reports.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :batch_run_pivot_reports, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#batch_run_reports(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::BatchRunReportsResponse #batch_run_reports(property: nil, requests: nil) ⇒ ::Google::Analytics::Data::V1beta::BatchRunReportsResponse
Returns multiple reports in a batch. All reports must be for the same GA4 Property.
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 461 def batch_run_reports request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::BatchRunReportsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.batch_run_reports..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "property" => request.property } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.batch_run_reports.timeout, metadata: , retry_policy: @config.rpcs.batch_run_reports.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :batch_run_reports, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the AnalyticsData Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
104 105 106 107 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 104 def configure yield @config if block_given? @config end |
#get_metadata(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::Metadata #get_metadata(name: nil) ⇒ ::Google::Analytics::Data::V1beta::Metadata
Returns metadata for dimensions and metrics available in reporting methods. Used to explore the dimensions and metrics. In this method, a Google Analytics GA4 Property Identifier is specified in the request, and the metadata response includes Custom dimensions and metrics as well as Universal metadata.
For example if a custom metric with parameter name levels_unlocked is
registered to a property, the Metadata response will contain
customEvent:levels_unlocked. Universal metadata are dimensions and
metrics applicable to any property such as country and totalUsers.
624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 624 def request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::GetMetadataRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs...to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs..timeout, metadata: , retry_policy: @config.rpcs..retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :get_metadata, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#run_pivot_report(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::RunPivotReportResponse #run_pivot_report(property: nil, dimensions: nil, metrics: nil, date_ranges: nil, pivots: nil, dimension_filter: nil, metric_filter: nil, currency_code: nil, cohort_spec: nil, keep_empty_rows: nil, return_property_quota: nil) ⇒ ::Google::Analytics::Data::V1beta::RunPivotReportResponse
Returns a customized pivot report of your Google Analytics event data. Pivot reports are more advanced and expressive formats than regular reports. In a pivot report, dimensions are only visible if they are included in a pivot. Multiple pivots can be specified to further dissect your data.
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 383 def run_pivot_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::RunPivotReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.run_pivot_report..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "property" => request.property } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.run_pivot_report.timeout, metadata: , retry_policy: @config.rpcs.run_pivot_report.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :run_pivot_report, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#run_realtime_report(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::RunRealtimeReportResponse #run_realtime_report(property: nil, dimensions: nil, metrics: nil, dimension_filter: nil, metric_filter: nil, limit: nil, metric_aggregations: nil, order_bys: nil, return_property_quota: nil, minute_ranges: nil) ⇒ ::Google::Analytics::Data::V1beta::RunRealtimeReportResponse
The Google Analytics Realtime API returns a customized report of realtime event data for your property. These reports show events and usage from the last 30 minutes.
732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 732 def run_realtime_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::RunRealtimeReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.run_realtime_report..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "property" => request.property } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.run_realtime_report.timeout, metadata: , retry_policy: @config.rpcs.run_realtime_report.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :run_realtime_report, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#run_report(request, options = nil) ⇒ ::Google::Analytics::Data::V1beta::RunReportResponse #run_report(property: nil, dimensions: nil, metrics: nil, date_ranges: nil, dimension_filter: nil, metric_filter: nil, offset: nil, limit: nil, metric_aggregations: nil, order_bys: nil, currency_code: nil, cohort_spec: nil, keep_empty_rows: nil, return_property_quota: nil) ⇒ ::Google::Analytics::Data::V1beta::RunReportResponse
Returns a customized report of your Google Analytics event data. Reports contain statistics derived from data collected by the Google Analytics tracking code. The data returned from the API is as a table with columns for the requested dimensions and metrics. Metrics are individual measurements of user activity on your property, such as active users or event count. Dimensions break down metrics across some common criteria, such as country or event name.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 268 def run_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Analytics::Data::V1beta::RunReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.run_report..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Analytics::Data::V1beta::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "property" => request.property } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.run_report.timeout, metadata: , retry_policy: @config.rpcs.run_report.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @analytics_data_stub.call_rpc :run_report, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |