Class: Google::Analytics::Data::V1beta::AnalyticsData::Client::Configuration
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::AnalyticsData::Client::Configuration
- Extended by:
- Gapic::Config
- Defined in:
- lib/google/analytics/data/v1beta/analytics_data/client.rb
Overview
Configuration class for the AnalyticsData API.
This class represents the configuration for AnalyticsData, providing control over timeouts, retry behavior, logging, transport parameters, and other low-level controls. Certain parameters can also be applied individually to specific RPCs. See Rpcs for a list of RPCs that can be configured independently.
Configuration can be applied globally to all clients, or to a single client on construction.
Examples
To modify the global config, setting the timeout for run_report to 20 seconds, and all remaining timeouts to 10 seconds:
::Google::Analytics::Data::V1beta::AnalyticsData::Client.configure do |config|
config.timeout = 10.0
config.rpcs.run_report.timeout = 20.0
end
To apply the above configuration only to a new client:
client = ::Google::Analytics::Data::V1beta::AnalyticsData::Client.new do |config|
config.timeout = 10.0
config.rpcs.run_report.timeout = 20.0
end
Defined Under Namespace
Classes: Rpcs
Instance Attribute Summary collapse
-
#channel_args ⇒ ::Hash
Extra parameters passed to the gRPC channel.
-
#credentials ⇒ ::Object
Credentials to send with calls.
-
#endpoint ⇒ ::String
The hostname or hostname:port of the service endpoint.
-
#interceptors ⇒ ::Array<::GRPC::ClientInterceptor>
An array of interceptors that are run before calls are executed.
-
#lib_name ⇒ ::String
The library name as recorded in instrumentation and logging.
-
#lib_version ⇒ ::String
The library version as recorded in instrumentation and logging.
-
#metadata ⇒ ::Hash{::Symbol=>::String}
Additional gRPC headers to be sent with the call.
-
#quota_project ⇒ ::String
A separate project against which to charge quota.
-
#retry_policy ⇒ ::Hash
The retry policy.
-
#scope ⇒ ::Array<::String>
The OAuth scopes.
-
#timeout ⇒ ::Numeric
The call timeout in seconds.
Instance Method Summary collapse
-
#rpcs ⇒ Rpcs
Configurations for individual RPCs.
Instance Attribute Details
#channel_args ⇒ ::Hash
Extra parameters passed to the gRPC channel. Note: this is ignored if a
GRPC::Core::Channel object is provided as the credential.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#credentials ⇒ ::Object
Credentials to send with calls. You may provide any of the following types:
- (
String) The path to a service account key file in JSON format - (
Hash) A service account key as a Hash - (
Google::Auth::Credentials) A googleauth credentials object (see the googleauth docs) - (
Signet::OAuth2::Client) A signet oauth2 client object (see the signet docs) - (
GRPC::Core::Channel) a gRPC channel with included credentials - (
GRPC::Core::ChannelCredentials) a gRPC credentails object - (
nil) indicating no credentials
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#endpoint ⇒ ::String
The hostname or hostname:port of the service endpoint.
Defaults to "analyticsdata.googleapis.com".
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#interceptors ⇒ ::Array<::GRPC::ClientInterceptor>
An array of interceptors that are run before calls are executed.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#lib_name ⇒ ::String
The library name as recorded in instrumentation and logging
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#lib_version ⇒ ::String
The library version as recorded in instrumentation and logging
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#metadata ⇒ ::Hash{::Symbol=>::String}
Additional gRPC headers to be sent with the call.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#quota_project ⇒ ::String
A separate project against which to charge quota.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#retry_policy ⇒ ::Hash
The retry policy. The value is a hash with the following keys:
:initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#scope ⇒ ::Array<::String>
The OAuth scopes
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
#timeout ⇒ ::Numeric
The call timeout in seconds.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 849 class Configuration extend ::Gapic::Config config_attr :endpoint, "analyticsdata.googleapis.com", ::String config_attr :credentials, nil do |value| allowed = [::String, ::Hash, ::Proc, ::Symbol, ::Google::Auth::Credentials, ::Signet::OAuth2::Client, nil] allowed += [::GRPC::Core::Channel, ::GRPC::Core::ChannelCredentials] if defined? ::GRPC allowed.any? { |klass| klass === value } end config_attr :scope, nil, ::String, ::Array, nil config_attr :lib_name, nil, ::String, nil config_attr :lib_version, nil, ::String, nil config_attr(:channel_args, { "grpc.service_config_disable_resolution" => 1 }, ::Hash, nil) config_attr :interceptors, nil, ::Array, nil config_attr :timeout, nil, ::Numeric, nil config_attr :metadata, nil, ::Hash, nil config_attr :retry_policy, nil, ::Hash, ::Proc, nil config_attr :quota_project, nil, ::String, nil # @private def initialize parent_config = nil @parent_config = parent_config unless parent_config.nil? yield self if block_given? end ## # Configurations for individual RPCs # @return [Rpcs] # def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end ## # Configuration RPC class for the AnalyticsData API. # # Includes fields providing the configuration for each RPC in this service. # Each configuration object is of type `Gapic::Config::Method` and includes # the following configuration fields: # # * `timeout` (*type:* `Numeric`) - The call timeout in seconds # * `metadata` (*type:* `Hash{Symbol=>String}`) - Additional gRPC headers # * `retry_policy (*type:* `Hash`) - The retry policy. The policy fields # include the following keys: # * `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. # * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. # * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. # * `:retry_codes` (*type:* `Array<String>`) - The error codes that should # trigger a retry. # class Rpcs ## # RPC-specific configuration for `run_report` # @return [::Gapic::Config::Method] # attr_reader :run_report ## # RPC-specific configuration for `run_pivot_report` # @return [::Gapic::Config::Method] # attr_reader :run_pivot_report ## # RPC-specific configuration for `batch_run_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_reports ## # RPC-specific configuration for `batch_run_pivot_reports` # @return [::Gapic::Config::Method] # attr_reader :batch_run_pivot_reports ## # RPC-specific configuration for `get_metadata` # @return [::Gapic::Config::Method] # attr_reader :get_metadata ## # RPC-specific configuration for `run_realtime_report` # @return [::Gapic::Config::Method] # attr_reader :run_realtime_report # @private def initialize parent_rpcs = nil run_report_config = parent_rpcs.run_report if parent_rpcs.respond_to? :run_report @run_report = ::Gapic::Config::Method.new run_report_config run_pivot_report_config = parent_rpcs.run_pivot_report if parent_rpcs.respond_to? :run_pivot_report @run_pivot_report = ::Gapic::Config::Method.new run_pivot_report_config batch_run_reports_config = parent_rpcs.batch_run_reports if parent_rpcs.respond_to? :batch_run_reports @batch_run_reports = ::Gapic::Config::Method.new batch_run_reports_config batch_run_pivot_reports_config = parent_rpcs.batch_run_pivot_reports if parent_rpcs.respond_to? :batch_run_pivot_reports @batch_run_pivot_reports = ::Gapic::Config::Method.new batch_run_pivot_reports_config = parent_rpcs. if parent_rpcs.respond_to? :get_metadata @get_metadata = ::Gapic::Config::Method.new run_realtime_report_config = parent_rpcs.run_realtime_report if parent_rpcs.respond_to? :run_realtime_report @run_realtime_report = ::Gapic::Config::Method.new run_realtime_report_config yield self if block_given? end end end |
Instance Method Details
#rpcs ⇒ Rpcs
Configurations for individual RPCs
879 880 881 882 883 884 885 |
# File 'lib/google/analytics/data/v1beta/analytics_data/client.rb', line 879 def rpcs @rpcs ||= begin parent_rpcs = nil parent_rpcs = @parent_config.rpcs if defined?(@parent_config) && @parent_config.respond_to?(:rpcs) Rpcs.new parent_rpcs end end |