Class: Google::Analytics::Data::V1beta::Dimension
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::Dimension
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/data/v1beta/data.rb
Overview
Dimensions are attributes of your data. For example, the dimension city indicates the city from which an event originates. Dimension values in report responses are strings; for example, city could be "Paris" or "New York". Requests are allowed up to 9 dimensions.
Instance Attribute Summary collapse
-
#dimension_expression ⇒ ::Google::Analytics::Data::V1beta::DimensionExpression
One dimension can be the result of an expression of multiple dimensions.
-
#name ⇒ ::String
The name of the dimension.
Instance Attribute Details
#dimension_expression ⇒ ::Google::Analytics::Data::V1beta::DimensionExpression
Returns One dimension can be the result of an expression of multiple dimensions. For example, dimension "country, city": concatenate(country, ", ", city).
105 106 107 108 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 105 class Dimension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The name of the dimension. See the API Dimensions for the list of dimension names.
If dimensionExpression is specified, name can be any string that you
would like within the allowed character set. For example if a
dimensionExpression concatenates country and city, you could call
that dimension countryAndCity. Dimension names that you choose must match
the regular expression "^[a-zA-Z0-9_]$".
Dimensions are referenced by name in dimensionFilter, orderBys,
dimensionExpression, and pivots.
105 106 107 108 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 105 class Dimension include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |