Class: Google::Analytics::Data::V1beta::OrderBy::DimensionOrderBy
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::OrderBy::DimensionOrderBy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/data/v1beta/data.rb
Overview
Sorts by dimension values.
Defined Under Namespace
Modules: OrderType
Instance Attribute Summary collapse
-
#dimension_name ⇒ ::String
A dimension name in the request to order by.
-
#order_type ⇒ ::Google::Analytics::Data::V1beta::OrderBy::DimensionOrderBy::OrderType
Controls the rule for dimension value ordering.
Instance Attribute Details
#dimension_name ⇒ ::String
Returns A dimension name in the request to order by.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 372 class DimensionOrderBy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rule to order the string dimension values by. module OrderType # Unspecified. ORDER_TYPE_UNSPECIFIED = 0 # Alphanumeric sort by Unicode code point. For example, "2" < "A" < "X" < # "b" < "z". ALPHANUMERIC = 1 # Case insensitive alphanumeric sort by lower case Unicode code point. # For example, "2" < "A" < "b" < "X" < "z". CASE_INSENSITIVE_ALPHANUMERIC = 2 # Dimension values are converted to numbers before sorting. For example # in NUMERIC sort, "25" < "100", and in `ALPHANUMERIC` sort, "100" < # "25". Non-numeric dimension values all have equal ordering value below # all numeric values. NUMERIC = 3 end end |
#order_type ⇒ ::Google::Analytics::Data::V1beta::OrderBy::DimensionOrderBy::OrderType
Returns Controls the rule for dimension value ordering.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 372 class DimensionOrderBy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Rule to order the string dimension values by. module OrderType # Unspecified. ORDER_TYPE_UNSPECIFIED = 0 # Alphanumeric sort by Unicode code point. For example, "2" < "A" < "X" < # "b" < "z". ALPHANUMERIC = 1 # Case insensitive alphanumeric sort by lower case Unicode code point. # For example, "2" < "A" < "b" < "X" < "z". CASE_INSENSITIVE_ALPHANUMERIC = 2 # Dimension values are converted to numbers before sorting. For example # in NUMERIC sort, "25" < "100", and in `ALPHANUMERIC` sort, "100" < # "25". Non-numeric dimension values all have equal ordering value below # all numeric values. NUMERIC = 3 end end |