Class: Google::Analytics::Data::V1beta::OrderBy::PivotOrderBy
- Inherits:
-
Object
- Object
- Google::Analytics::Data::V1beta::OrderBy::PivotOrderBy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/analytics/data/v1beta/data.rb
Overview
Sorts by a pivot column group.
Defined Under Namespace
Classes: PivotSelection
Instance Attribute Summary collapse
-
#metric_name ⇒ ::String
In the response to order by, order rows by this column.
-
#pivot_selections ⇒ ::Array<::Google::Analytics::Data::V1beta::OrderBy::PivotOrderBy::PivotSelection>
Used to select a dimension name and value pivot.
Instance Attribute Details
#metric_name ⇒ ::String
Returns In the response to order by, order rows by this column. Must be a metric name from the request.
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 408 class PivotOrderBy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A pair of dimension names and values. Rows with this dimension pivot pair # are ordered by the metric's value. # # For example if pivots = \\{\\{"browser", "Chrome"}} and # metric_name = "Sessions", # then the rows will be sorted based on Sessions in Chrome. # # ---------|----------|----------------|----------|---------------- # | Chrome | Chrome | Safari | Safari # ---------|----------|----------------|----------|---------------- # Country | Sessions | Pages/Sessions | Sessions | Pages/Sessions # ---------|----------|----------------|----------|---------------- # US | 2 | 2 | 3 | 1 # ---------|----------|----------------|----------|---------------- # Canada | 3 | 1 | 4 | 1 # ---------|----------|----------------|----------|---------------- # @!attribute [rw] dimension_name # @return [::String] # Must be a dimension name from the request. # @!attribute [rw] dimension_value # @return [::String] # Order by only when the named dimension is this value. class PivotSelection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pivot_selections ⇒ ::Array<::Google::Analytics::Data::V1beta::OrderBy::PivotOrderBy::PivotSelection>
Returns Used to select a dimension name and value pivot. If multiple pivot selections are given, the sort occurs on rows where all pivot selection dimension name and value pairs match the row's dimension name and value pair.
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'proto_docs/google/analytics/data/v1beta/data.rb', line 408 class PivotOrderBy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A pair of dimension names and values. Rows with this dimension pivot pair # are ordered by the metric's value. # # For example if pivots = \\{\\{"browser", "Chrome"}} and # metric_name = "Sessions", # then the rows will be sorted based on Sessions in Chrome. # # ---------|----------|----------------|----------|---------------- # | Chrome | Chrome | Safari | Safari # ---------|----------|----------------|----------|---------------- # Country | Sessions | Pages/Sessions | Sessions | Pages/Sessions # ---------|----------|----------------|----------|---------------- # US | 2 | 2 | 3 | 1 # ---------|----------|----------------|----------|---------------- # Canada | 3 | 1 | 4 | 1 # ---------|----------|----------------|----------|---------------- # @!attribute [rw] dimension_name # @return [::String] # Must be a dimension name from the request. # @!attribute [rw] dimension_value # @return [::String] # Order by only when the named dimension is this value. class PivotSelection include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |